
.. all-saltext.vmware.modules:

-----------------
Execution Modules
-----------------

.. autosummary::
    :toctree:

    saltext.elasticsearch.modules.__init__
    saltext.elasticsearch.modules.elasticsearch_mod
    saltext.elasticsearch.modules.es_module_6
    saltext.elasticsearch.modules.es_module_8
